# coding: utf-8

"""
    ARTIK Cloud API

    OpenAPI spec version: 2.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import os
import sys
import time
import unittest

import artikcloud
from artikcloud.rest import ApiException
from artikcloud.apis.messages_api import MessagesApi
from artikcloud.models.action import Action
from artikcloud.models.actions import Actions
from artikcloud.models.action_array import ActionArray
from test.test_artik_base import TestArtikBase

class TestMessagesApi(TestArtikBase):
    """ MessagesApi unit test stubs """

    def setUp(self):
        configuration = artikcloud.Configuration();
        configuration.access_token = self.properties['device1.token']
        self.api = MessagesApi()

    def tearDown(self):
        pass

    def test_get_aggregates_histogram(self):
        """
        Test case for get_aggregates_histogram

        Get Normalized Message Histogram
        """
        pass

    def test_get_field_presence(self):
        """
        Test case for get_field_presence

        Get normalized message presence
        """
        pass

    def test_get_last_normalized_messages(self):
        """
        Test case for get_last_normalized_messages

        Get Last Normalized Message
        """
        pass

    def test_get_message_aggregates(self):
        """
        Test case for get_message_aggregates

        Get Normalized Message Aggregates
        """
        pass

    def test_get_message_snapshots(self):
        """
        Test case for get_message_snapshots

        Get Message Snapshots
        """
        sdids = self.properties['device1.id']

        env = self.api.get_message_snapshots(sdids, include_timestamp=False)

        self.assertEqual(sdids, env.sdids, 'SDIDs must match')
        self.assertEqual(sdids, env.data[0].sdid, 'SDID must match')

        steps_info = env.data[0].data['steps']
        self.assertEqual(500.0, steps_info['value'], 'Steps must be 500')

    def test_get_normalized_actions(self):
        """
        Test case for get_normalized_actions

        Get Normalized Actions
        """
        pass

    def test_get_normalized_messages(self):
        """
        Test case for get_normalized_messages

        Get Normalized Messages
        """
        pass

    def test_send_actions(self):
        """
        Test case for send_actions

        Send Actions
        """
        ddid = self.properties['device4.id']

        configuration = artikcloud.Configuration();
        configuration.access_token = self.properties['device4.token']
        api = MessagesApi()

        action = Action()
        action.name = 'setVolume'
        action.parameters = {'volume': 5}

        action_array = ActionArray()
        action_array.actions = [ action ]

        actions = Actions()
        actions.ddid = ddid
        actions.ts = int(round(time.time() * 1000))
        actions.data = action_array

        mid = api.send_actions(actions).data.mid

        time.sleep(2)

        envelope = api.get_normalized_actions(mid=mid)
        self.assertEqual(1, envelope.size)

        normalized = envelope.data[0]
        action_rx = normalized.data.actions[0]

        self.assertEqual('setVolume', action_rx.name)
        volume = action_rx.parameters['volume']

        self.assertIsNotNone(volume, 'Volume should not be None')
        self.assertEqual(5.0, volume)


    def test_send_message(self):
        """
        Test case for send_message

        Send Message
        """
        message = artikcloud.Message()
        message.type = "message"
        message.sdid = self.properties['device1.id']
        message.ts = int(round(time.time() * 1000))
        message.data = {'steps': 500}

        response = self.api.send_message(message)
        self.assertIsNotNone(response)
        messageid = response.data.mid
        self.assertIsNotNone(messageid, 'Message ID should not be None')

        # get normalized message from mid
        time.sleep(1)
        envelope = self.api.get_normalized_messages(mid=messageid)
        self.assertIsNotNone(envelope)
        self.assertEqual(envelope.size, 1)

        normalized = envelope.data[0]
        self.assertIsNotNone(normalized)
        self.assertEqual(normalized.mid, messageid)

        steps = normalized.data['steps']
        self.assertIsNotNone(steps)
        self.assertEqual(steps, 500.0)


if __name__ == '__main__':
    unittest.main()
